/// <reference types="react" />
import * as _ from "lodash";
import { DiagramEngine } from "../DiagramEngine";
import { BaseAction } from "../actions/BaseAction";
import { BaseModel, BaseModelListener } from "../models/BaseModel";
import { BaseEntity } from "../BaseEntity";
import { BaseWidget, BaseWidgetProps } from "./BaseWidget";
export interface DiagramProps extends BaseWidgetProps {
    diagramEngine: DiagramEngine;
    allowLooseLinks?: boolean;
    allowCanvasTranslation?: boolean;
    maxNumberPointsPerLink?: number;
    connectors?: boolean;
    smartRouting?: boolean;
    rightAnglesRouting?: boolean;
    highlightPorts?: "none" | "valid" | "all";
    actionStartedFiring?: (action: BaseAction) => boolean;
    actionStillFiring?: (action: BaseAction) => void;
    actionStoppedFiring?: (action: BaseAction) => void;
    deleteKeys?: number[];
    drawMatrix?: boolean;
}
export interface DiagramState {
    action: BaseAction | null;
    wasMoved: boolean;
    renderedNodes: boolean;
    windowListener: any;
    diagramEngineListener: any;
    document: any;
    modelId: string;
}
/**
 * @author Dylan Vorster, Iliya Krastinkov
 *
 * Responsibility: Wire components hierarchy and events.
 */
export declare class DiagramWidget extends BaseWidget<DiagramProps, DiagramState> {
    static defaultProps: DiagramProps;
    onKeyUpPointer: (this: Window, ev: KeyboardEvent) => void;
    reattachEngineListener: ((diagramEngine: DiagramEngine) => void) & _.MemoizedFunction;
    constructor(props: DiagramProps);
    componentWillUnmount(): void;
    static getDerivedStateFromProps(props: any, state: any): any;
    componentDidUpdate(prevProps: Readonly<DiagramProps>, prevState: Readonly<DiagramState>, snapshot?: any): void;
    componentDidMount(): void;
    onMouseDown: (event: MouseEvent) => void;
    /**
     * Gets a model and element under the mouse cursor
     */
    getMouseElement(event: any): {
        model: BaseModel<BaseEntity, BaseModelListener>;
        element: Element;
    };
    fireAction(): void;
    stopFiringAction(shouldSkipEvent?: boolean): void;
    startFiringAction(action: BaseAction): void;
    onMouseMove(event: any): void;
    onKeyUp(event: any): void;
    onMouseUp(event: any): void;
    onWheel: (event: any) => void;
    drawSelectionBox(): JSX.Element;
    render(): JSX.Element;
}
